@@ -14,8 +14,6 @@
 
 #include <string>
 
-using namespace std;
-
 namespace siena
 {
 
@@ -26,17 +24,17 @@ namespace siena
 class EffectInfo
 {
 public:
-	EffectInfo(string variableName,
-		string effectName,
-		string effectType,
+	EffectInfo(std::string variableName,
+		std::string effectName,
+		std::string effectType,
 		double parameter,
 		double internalEffectParameter,
-		string interactionName1,
-		string interactionName2,
-		string rateType);
-	EffectInfo(string variableName,
-		string effectName,
-		string effectType,
+		std::string interactionName1,
+		std::string interactionName2,
+		std::string rateType);
+	EffectInfo(std::string variableName,
+		std::string effectName,
+		std::string effectType,
 		double parameter,
 		const EffectInfo * pEffect1,
 		const EffectInfo * pEffect2,
@@ -44,28 +42,28 @@ public:
 
 	void parameter(double value);
 
-	string variableName() const;
-	string effectName() const;
+	std::string variableName() const;
+	std::string effectName() const;
+	std::string effectType() const;
 	double parameter() const;
 	double internalEffectParameter() const;
-	string interactionName1() const;
-	string interactionName2() const;
-	string rateType() const;
+	std::string interactionName1() const;
+	std::string interactionName2() const;
+	std::string rateType() const;
 	const EffectInfo * pEffectInfo1() const;
 	const EffectInfo * pEffectInfo2() const;
 	const EffectInfo * pEffectInfo3() const;
 
 private:
 	// The name of the variable this effect is associated with
-	string lvariableName;
+	std::string lvariableName;
 
 	// A short name of the effect used to identify the semantics
 	// of this effect
-
-	string leffectName;
+	std::string leffectName;
 
 	// The type of the effect ("rate", "eval", or "endow")
-	string leffectType;
+	std::string leffectType;
 
 	// The multiplicative weight in the respective function
 	double lparameter;
@@ -75,21 +73,18 @@ private:
 
 	// The name of a variable or covariate this effect is interacting with,
 	// if applicable
-
-	string linteractionName1;
+	std::string linteractionName1;
 
 	// The name of the other interaction variable or covariate, if the
 	// effect has two such interactions
-
-	string linteractionName2;
+	std::string linteractionName2;
 
 	// Distinguishes between structural rate effects and covariate rate effects
-	string lrateType;
+	std::string lrateType;
 
 	// The interacting effect descriptions.
 	// Undefined for non-interaction effects.
 	// The third effect is undefined for two-way interactions.
-
 	const EffectInfo * lpEffectInfo1;
 	const EffectInfo * lpEffectInfo2;
 	const EffectInfo * lpEffectInfo3;
