@@ -46,23 +46,20 @@ double LinearShapeEffect::egoStatistic(int ego, double * currentValues)
 
 
 /**
- * Returns the statistic corresponding to this effect as part of
+ * Returns the statistic corresponding to the given ego as part of
  * the endowment function with respect to the initial values of a
  * behavior variable and the current values.
  */
-double LinearShapeEffect::endowmentStatistic(const int * difference,
+double LinearShapeEffect::egoEndowmentStatistic(int ego,
+	const int * difference,
 	double * currentValues)
 {
 	double statistic = 0;
 
-	int n = this->n();
-
-	for (int i = 0; i < n; i++)
+	if (difference[ego] > 0)
 	{
-		if (difference[i] > 0)
-		{
-			statistic += currentValues[i]  ;
-		}
+		//	statistic = currentValues[ego] ;
+		statistic -= difference[ego];
 	}
 
 	return statistic;
