@@ -28,7 +28,11 @@ enum StructuralRateEffectType
 	IN_DEGREE_RATE,
 	RECIPROCAL_DEGREE_RATE,
 	INVERSE_OUT_DEGREE_RATE,
-	LOG_OUT_DEGREE_RATE
+	LOG_OUT_DEGREE_RATE,
+	INVERSE_IN_DEGREE_RATE,
+	LOG_IN_DEGREE_RATE,
+	INVERSE_RECIPROCAL_DEGREE_RATE,
+	LOG_RECIPROCAL_DEGREE_RATE
 };
 
 
