@@ -14,7 +14,6 @@
 #include "model/State.h"
 #include "model/tables/Cache.h"
 
-using namespace std;
 namespace siena
 {
 
@@ -23,12 +22,10 @@ AlterFunction::AlterFunction()
 	this->lego = -1;
 }
 
-
 AlterFunction::~AlterFunction()
 {
 }
 
-
 /**
  * Initializes this function.
  * @param[in] pData the observed data
@@ -37,13 +34,10 @@ AlterFunction::~AlterFunction()
  * @param[in] pCache the cache object to be used to speed up calculations
  */
 void AlterFunction::initialize(const Data * pData,
-	State * pState,
-	int period,
-	Cache * pCache)
+		State * pState, int period, Cache * pCache)
 {
 }
 
-
 /**
  * Does the necessary preprocessing work for calculating the alter
  * function for a specific ego. This method must be invoked before
