@@ -32,4 +32,4 @@ private:
 
 }
 
-#endif /* COVARIATEDISTANCE2INSIMNETWORKFUNCTION_H_ */
+#endif /* COVARIATEDISTANCE2EGOALTSIMNETWORKFUNCTION_H_ */
