@@ -25,7 +25,7 @@ namespace siena
 class OutTieFunction: public NetworkAlterFunction
 {
 public:
-	OutTieFunction(string networkName);
+	OutTieFunction(std::string networkName);
 
 	virtual double value(int alter);
 };
