@@ -7,12 +7,13 @@
  *
  * Description: This file contains the implementation of the class Chain.
  *****************************************************************************/
-#include <Rinternals.h>
 
 #include <vector>
 #include <stdexcept>
 #include <string>
 
+#include <Rinternals.h>
+
 #include "Chain.h"
 #include "utils/Utils.h"
 #include "utils/Random.h"
@@ -510,7 +511,7 @@ void Chain::connect(int period, MLSimulation * pMLSimulation)
 								MiniStep * pFirstMiniStep =
 									this->pFirstMiniStepForLink(miniSteps[i]);
 								//	if (pFirstMiniStep != this->lpFirst)
-								//{
+								// {
 								//	PrintValue(getMiniStepDF(*pFirstMiniStep));
 								pMiniStep =
 									this->randomMiniStep(this->
@@ -524,7 +525,7 @@ void Chain::connect(int period, MLSimulation * pMLSimulation)
 								// see if valid here
 								if (pVariable->validMiniStep(miniSteps[i]))
 								{
-									Rprintf("thirsd true val\n");
+								//	Rprintf("third true val\n");
 									valid = true;
 								}
 								//	}
